"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var facebook_1 = require("./facebook");
var google_1 = require("./google");
var app = require("tns-core-modules/application");
if (app.ios) {
    require('./configure-ios-delegate');
}
var instance;
var Authentication = (function () {
    function Authentication(params) {
        var _this = this;
        app.on(app.launchEvent, function () {
            if (params.facebook) {
                _this.facebook = new facebook_1.Facebook(params.facebook);
                _this.facebook.initialize();
            }
            if (params.google) {
                _this.google = new google_1.Google(params.google);
                _this.google.initialize();
            }
        });
        instance = this;
    }
    Object.defineProperty(Authentication, "instance", {
        get: function () {
            return instance;
        },
        enumerable: true,
        configurable: true
    });
    Authentication.prototype.login = function (driver) {
        var _this = this;
        driver = driver.toLowerCase();
        if (Authentication.drivers.indexOf(driver) < 0) {
            throw new Error("The driver \"" + driver + "\" is not supported.");
        }
        return exports.waitForAppLaunch(function () { return _this[driver].login(); });
    };
    Authentication.prototype.logout = function () {
        var _this = this;
        return exports.waitForAppLaunch(function () {
            return Promise.all([Authentication.drivers.map(function (driver) { return _this[driver].logout(); })]);
        });
    };
    Authentication.prototype.user = function () {
        var _this = this;
        return exports.waitForAppLaunch(function () {
            return _this.driverInUse
                ? _this.driverInUse.getCurrentUser()
                : new Promise(function (resolve) { return resolve(null); });
        });
    };
    Object.defineProperty(Authentication.prototype, "token", {
        get: function () {
            return this.driverInUse ? this.driverInUse.getCurrentToken() : null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Authentication.prototype, "driver", {
        get: function () {
            return this.driverInUse ? this.driverInUse.driverName : null;
        },
        set: function (driver) {
            this.driverInUse = this[driver];
        },
        enumerable: true,
        configurable: true
    });
    Authentication.drivers = ['facebook', 'google'];
    return Authentication;
}());
exports.waitForAppLaunch = function (callback) {
    if (app.hasLaunched()) {
        return callback();
    }
    else {
        return new Promise(function (resolve) {
            app.on(app.launchEvent, function () { return resolve(callback()); });
        });
    }
};
__export(require("./ui/facebook-login-button"));
__export(require("./ui/google-login-button"));
exports.GoogleInstance = function () { return Authentication.instance.google; };
exports.FacebookInstance = function () { return Authentication.instance.facebook; };
exports.default = Authentication;
//# sourceMappingURL=authentication.js.map