"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var facebook_common_1 = require("./facebook.common");
var user_1 = require("./user");
var Facebook = (function (_super) {
    __extends(Facebook, _super);
    function Facebook() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Facebook.prototype.initialize = function () {
        FBSDKSettings.setAppID(this.id);
        this.manager = FBSDKLoginManager.alloc().init();
        this.initializeUser();
    };
    Facebook.prototype.login = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this.loginCallback = function (user) { return resolve(user); };
            _this.errorCallback = function (error) { return reject(error); };
            _this.manager.logInWithReadPermissionsHandler(NSArray.arrayWithArray(_this.permissions), _this.handleLogin.bind(_this));
        });
    };
    Facebook.prototype.logout = function () {
        var _this = this;
        return new Promise(function (resolve) {
            _this.logoutCallback = function (value) { return resolve(value); };
            _this.manager.logOut();
            _this.logoutCallback();
        });
    };
    Facebook.prototype.handleLogin = function (data, error) {
        var _this = this;
        if (error) {
            this.errorCallback(error);
        }
        else if (data.isCancelled) {
            this.errorCallback('Login cancelled.');
        }
        this.fetchUser(data.token.tokenString).then(function (user) {
            return _this.loginCallback(user);
        });
    };
    Facebook.prototype.fetchUser = function (token) {
        var dict = NSDictionary.dictionaryWithObjectForKey(this.fields.join(','), 'fields');
        var request = FBSDKGraphRequest.alloc().initWithGraphPathParametersTokenStringVersionHTTPMethod('me', dict, token, null, 'GET');
        return new Promise(function (resolve) {
            request.startWithCompletionHandler(function (params, data) {
                data.token = token;
                resolve(new user_1.default(data, 'facebook'));
            });
        });
    };
    Facebook.prototype.getCurrentToken = function () {
        return FBSDKAccessToken.currentAccessToken()
            ? FBSDKAccessToken.currentAccessToken().tokenString
            : null;
    };
    Facebook.prototype.getCurrentUser = function () {
        return this.fetchUser(this.getCurrentToken());
    };
    return Facebook;
}(facebook_common_1.Facebook));
exports.Facebook = Facebook;
//# sourceMappingURL=facebook.ios.js.map