"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var google_common_1 = require("./google.common");
var app = require("tns-core-modules/application");
var user_1 = require("./user");
var _a = com.google.android.gms.auth.api.signin, GoogleSignIn = _a.GoogleSignIn, GoogleSignInOptions = _a.GoogleSignInOptions;
var SIGN_IN_INTENT = 3195;
var Google = (function (_super) {
    __extends(Google, _super);
    function Google() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Google.prototype.initialize = function () {
        var context = app.android.context.getApplicationContext();
        var options = new GoogleSignInOptions.Builder();
        if (this.scopes.indexOf('profile') > -1) {
            options.requestProfile();
        }
        if (this.scopes.indexOf('email') > -1) {
            options.requestEmail();
        }
        if (this.serverId) {
            options.requestServerAuthCode(this.serverId, false);
        }
        this.fields = this.fields;
        this.manager = GoogleSignIn.getClient(context, options.build());
        this.initializeUser();
    };
    Google.prototype.login = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this.errorCallback = function (error) { return reject(error); };
            _this.loginCallback = function (user) { return resolve(new user_1.default(user, 'google')); };
            _this.listenLogin();
        });
    };
    Google.prototype.listenLogin = function () {
        var intent = this.manager.getSignInIntent();
        app.android.startActivity.startActivityForResult(intent, SIGN_IN_INTENT);
        this.subscribe();
    };
    Google.prototype.logout = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            _this.errorCallback = function (error) { return reject(error); };
            _this.logoutCallback = function (value) { return resolve(value); };
            _this.manager.signOut();
            _this.logoutCallback();
        });
    };
    Google.prototype.getCurrentToken = function () {
        var context = app.android.context.getApplicationContext();
        return GoogleSignIn.getLastSignedInAccount(context)
            ? GoogleSignIn.getLastSignedInAccount(context).getIdToken()
            : null;
    };
    Google.prototype.getCurrentUser = function () {
        return new Promise(function (resolve) {
            var context = app.android.context.getApplicationContext();
            resolve(new user_1.default(GoogleSignIn.getLastSignedInAccount(context), 'google'));
        });
    };
    Google.prototype.subscribe = function () {
        var _this = this;
        var activityResultEvent = app.AndroidApplication.activityResultEvent;
        app.android.on(activityResultEvent, function (args) {
            try {
                if (args.requestCode === SIGN_IN_INTENT) {
                    var result = GoogleSignIn.getSignedInAccountFromIntent(args.intent).getResult();
                    _this.loginCallback(result);
                }
            }
            catch (error) {
                console.log(error);
                _this.errorCallback(error);
            }
        });
    };
    return Google;
}(google_common_1.Google));
exports.Google = Google;
//# sourceMappingURL=google.android.js.map